@@ -9,15 +9,16 @@
 #      S2 --c3--> S1 + S1
 #      S2 --c4--> S3
 
-parms <- c(c1=1.0, c2=0.002, c3=0.5, c4=0.04)
-x0 <- c(s1=10000, s2=0, s3=0)      # Initial state vector
-nu <- matrix(c(-1, -2, +2,  0,     # State-change matrix
+library(GillespieSSA)
+parms <- c(c1=1.0, c2=0.002, c3=0.5, c4=0.04) # Define parameters
+x0 <- c(s1=10000, s2=0, s3=0)                 # Initial state vector
+nu <- matrix(c(-1, -2, +2,  0,                # State-change matrix
                 0, +1, -1, -1,
                 0,  0,  0, +1),
                 nrow=3,byrow=TRUE)
 a  <- c("c1*{s1}", "c2*{s1}*{s1}", 
-        "c3*{s2}", "c4*{s2}")      # Propensity vector
-tf <- 30                           # Final time
+        "c3*{s2}", "c4*{s2}")                 # Propensity vector
+tf <- 30                                      # Final time
 simName <- "Decaying-Dimerizing Reaction Set"
 
 # Run simulations 
